@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-
-
 __doc__ = """GNUmed internetworking tools."""
 
 #===========================================================================
@@ -155,10 +153,19 @@ def compare_versions(left_version, right_version):
 	-1: left < right
 	 1: left > right
 	"""
+	_log.debug('comparing [%s] with [%s]', left_version, right_version)
 	if left_version == right_version:
-		_log.debug('same version: [%s] = [%s]', left_version, right_version)
+		_log.debug('same version')
 		return 0
 
+	if right_version in ['head', 'dev', 'devel']:
+		_log.debug('development code')
+		return -1
+
+	if left_version in ['head', 'dev', 'devel']:
+		_log.debug('development code')
+		return 1
+
 	left_parts = left_version.split('.')
 	right_parts = right_version.split('.')
 
@@ -194,8 +201,12 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 	False: up to date
 	None: don't know
 	"""
-	if current_version == 'GIT HEAD':
-		_log.debug('GIT HEAD always up to date')
+	if current_version is None:
+		_log.debug('<current_version> is None, currency unknown')
+		return (None, None)
+
+	if current_version.lower() in ['git head', 'head', 'tip', 'dev', 'devel']:
+		_log.debug('[%s] always considered up to date', current_version)
 		return (False, None)
 
 	try:
