@@ -300,6 +300,7 @@ def __request_login_params_tui():
 		gmLog2.add_word2hide(login.password)
 		login.port = prompted_input(prompt = "port", default = 5432)
 	except KeyboardInterrupt:
+		del login
 		_log.warning("user cancelled text mode login dialog")
 		print("user cancelled text mode login dialog")
 		raise gmExceptions.ConnectionError(_("Cannot connect to database without login information!"))
@@ -346,21 +347,28 @@ def __request_login_params_gui_wx():
 	return login, creds
 
 #---------------------------------------------------
-def request_login_params():
+def request_login_params(setup_pool=False):
 	"""Request login parameters for database connection."""
-
 	# are we inside X ?
 	# if we aren't wxGTK will crash hard at the C-level with "can't open Display"
 	if 'DISPLAY' in os.environ:
 		# try wxPython GUI
 		try:
-			return __request_login_params_gui_wx()
+			login, creds = __request_login_params_gui_wx()
 		except Exception:
 			pass
+		if setup_pool:
+			pool = gmConnectionPool.gmConnectionPool()
+			pool.credentials = creds
+		return login, creds
 
 	# well, either we are on the console or
 	# wxPython does not work, use text mode
-	return __request_login_params_tui()
+	login, creds = __request_login_params_tui()
+	if setup_pool:
+		pool = gmConnectionPool.gmConnectionPool()
+		pool.credentials = creds
+	return login, creds
 
 # =======================================================================
 # netadata API
@@ -435,6 +443,70 @@ def get_schema_revision_history(link_obj=None):
 
 	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': cmd}])
 	return rows
+
+#------------------------------------------------------------------------
+def get_db_fingerprint(conn=None, fname=None, with_dump=False, eol=None):
+	queries = [
+		("SELECT setting FROM pg_settings WHERE name = 'server_version'", "Version (PG)"),
+		("SELECT setting FROM pg_settings WHERE name = 'server_encoding'", "Encoding (PG)"),
+		("SELECT setting FROM pg_settings WHERE name = 'lc_collate'", "LC_COLLATE (PG)"),
+		("SELECT setting FROM pg_settings WHERE name = 'lc_ctype'", "LC_CTYPE (PG)"),
+		("SELECT count(1) FROM dem.identity", "Patients"),
+		("SELECT count(1) FROM clin.encounter", "Contacts"),
+		("SELECT count(1) FROM clin.episode", "Episodes"),
+		("SELECT count(1) FROM clin.health_issue", "Issues"),
+		("SELECT count(1) FROM clin.test_result", "Results"),
+		("SELECT count(1) FROM clin.vaccination", "Vaccinations"),
+		("SELECT count(1) FROM blobs.doc_med", "Documents"),
+		("SELECT count(1) FROM blobs.doc_obj", "Objects"),
+		("SELECT count(1) FROM dem.org", "Organizations"),
+		("SELECT count(1) FROM dem.org_unit", "Organizational units"),
+		("SELECT max(modified_when) FROM audit.audit_fields", "Most recent .modified_when"),
+		("SELECT max(audit_when) FROM audit.audit_trail", "Most recent .audit_when")
+	]
+	if conn is None:
+		conn = get_connection(readonly = True)
+	database = conn.get_dsn_parameters()['dbname']
+	lines = [
+		'Fingerprinting GNUmed database ...',
+		'',
+		'%20s: %s' % ('Name (DB)', database)
+	]
+	curs = conn.cursor()
+	# get size
+	cmd = "SELECT pg_size_pretty(pg_database_size('%s'))" % database
+	curs.execute(cmd)
+	rows = curs.fetchall()
+	lines.append('%20s: %s' % ('Size (DB)', rows[0][0]))
+	# get hash
+	cmd = "SELECT md5(gm.concat_table_structure())"
+	curs.execute(cmd)
+	rows = curs.fetchall()
+	md5_sum = rows[0][0]
+	try:
+		lines.append('%20s: %s (v%s)' % ('Schema hash', md5_sum, map_schema_hash2version[md5_sum]))
+	except KeyError:
+		lines.append('%20s: %s' % ('Schema hash', md5_sum))
+	for cmd, label in queries:
+		curs.execute(cmd)
+		rows = curs.fetchall()
+		lines.append('%20s: %s' % (label, rows[0][0]))
+	if with_dump:
+		curs.execute('SELECT gm.concat_table_structure()')
+		rows = curs.fetchall()
+		lines.append('')
+		lines.append(rows[0][0])
+	curs.close()
+	if fname is None:
+		if eol is None:
+			return lines
+		return eol.join(lines)
+
+	outfile = open(fname, mode = 'wt', encoding = 'utf8')
+	outfile.write('\n'.join(lines))
+	outfile.close()
+	return fname
+
 #------------------------------------------------------------------------
 def get_current_user():
 	rows, idx = run_ro_queries(queries = [{'cmd': 'select CURRENT_USER'}])
@@ -1803,7 +1875,7 @@ def run_insert(link_obj=None, schema=None, table=None, values=None, returning=No
 	if schema is None:
 		schema = 'public'
 
-	fields = values.keys()		# that way val_snippets and fields really should end up in the same order
+	fields = list(values)		# that way val_snippets and fields really should end up in the same order
 	val_snippets = []
 	for field in fields:
 		val_snippets.append('%%(%s)s' % field)
@@ -1841,11 +1913,11 @@ def run_insert(link_obj=None, schema=None, table=None, values=None, returning=No
 # =======================================================================
 # connection handling API
 # -----------------------------------------------------------------------
-def get_raw_connection(dsn=None, verbose=False, readonly=True, connection_name=None, autocommit=False):
+def get_raw_connection(verbose=False, readonly=True, connection_name=None, autocommit=False):
 	"""Get a raw, unadorned connection.
 
 	- this will not set any parameters such as encoding, timezone, datestyle
-	- the only requirement is a valid DSN
+	- the only requirement is valid connection parameters having been passed to the connection pool
 	- hence it can be used for "service" connections
 	  for verifying encodings etc
 	"""
@@ -1857,7 +1929,7 @@ def get_raw_connection(dsn=None, verbose=False, readonly=True, connection_name=N
 	)
 
 # =======================================================================
-def get_connection(dsn=None, readonly=True, verbose=False, pooled=True, connection_name=None, autocommit=False):
+def get_connection(readonly=True, verbose=False, pooled=True, connection_name=None, autocommit=False):
 	return gmConnectionPool.gmConnectionPool().get_connection (
 		readonly = readonly,
 		verbose = verbose,
@@ -1986,7 +2058,7 @@ def sanity_check_database_settings():
 	cmd = "SELECT name, setting from pg_settings where name in %(settings)s"
 	rows, idx = run_ro_queries (
 		link_obj = conn,
-		queries = [{'cmd': cmd, 'args': {'settings': tuple(options2check.keys())}}],
+		queries = [{'cmd': cmd, 'args': {'settings': tuple(options2check)}}],
 		get_col_idx = False
 	)
 
@@ -2024,7 +2096,6 @@ def sanity_check_database_settings():
 #=======================================================================
 #  main
 #-----------------------------------------------------------------------
-log_pg_settings = gmConnectionPool.log_pg_settings
 log_pg_exception_details = gmConnectionPool.log_pg_exception_details
 
 exception_is_connection_loss = gmConnectionPool.exception_is_connection_loss
@@ -2514,6 +2585,15 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 		conn = get_connection()
 		gmConnectionPool.log_pg_settings(curs = conn.cursor())
 
+	#--------------------------------------------------------------------
+	def test_get_db_fingerprint():
+		login, creds = request_login_params()
+		pool = gmConnectionPool.gmConnectionPool()
+		pool.credentials = creds
+		#conn = get_connection()
+		#print(get_db_fingerprint(conn, with_dump = True, eol = '\n'))
+		print(get_db_fingerprint(with_dump = True, eol = '\n'))
+
 	#--------------------------------------------------------------------
 	# run tests
 
@@ -2536,11 +2616,12 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 	#test_get_index_name()
 	#test_set_user_language()
 	#test_get_schema_revision_history()
-	test_run_query()
+	#test_run_query()
 	#test_schema_exists()
 	#test_get_foreign_key_names()
 	#test_row_locks()
 	#test_faulty_SQL()
-	test_log_settings()
+	#test_log_settings()
+	test_get_db_fingerprint()
 
 # ======================================================================
