@@ -134,7 +134,7 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 
 		gmLog2.add_word2hide(login.password)
 
-		# try getting a connection to verify the DSN works
+		# try getting a connection to verify the parameters work
 		creds = gmConnectionPool.cPGCredentials()
 		creds.database = login.database
 		creds.host = login.host
@@ -275,6 +275,12 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 		gmExceptionHandlingWidgets.set_is_public_database(_cfg.get(option = 'is_public_db'))
 		gmExceptionHandlingWidgets.set_helpdesk(_cfg.get(option = 'helpdesk'))
 
+		gmLog2.log_multiline (
+			logging.DEBUG,
+			message = 'fingerprint',
+			text = gmPG2.get_db_fingerprint(eol = '\n')
+		)
+
 		conn = gmPG2.get_connection(verbose = True, connection_name = 'GNUmed-[DbListenerThread]', pooled = False)
 		listener = gmBackendListener.gmBackendListener(conn = conn)
 		break
@@ -513,10 +519,10 @@ class cLoginPanel(wx.Panel):
 		self._CBOX_profile = wx.ComboBox (
 			self,
 			-1,
-			list(self.__backend_profiles.keys())[0],
+			list(self.__backend_profiles)[0],
 			wx.DefaultPosition,
 			size = wx.Size(550,-1),
-			choices = list(self.__backend_profiles.keys()),
+			choices = list(self.__backend_profiles),
 			style = wx.CB_READONLY
 		)
 		self.pboxgrid.Add (self._CBOX_profile, 0, wx.GROW|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5)
@@ -741,10 +747,10 @@ class cLoginPanel(wx.Panel):
 		)
 
 		last_used_profile_label = _cfg.get('preferences', 'profile', src_order)
-		if last_used_profile_label in self.__backend_profiles.keys():
+		if last_used_profile_label in self.__backend_profiles:
 			self._CBOX_profile.SetValue(last_used_profile_label)
 		else:
-			self._CBOX_profile.SetValue(list(self.__backend_profiles.keys())[0])
+			self._CBOX_profile.SetValue(list(self.__backend_profiles)[0])
 
 		self._CHBOX_debug.SetValue(_cfg.get(option = 'debug'))
 		self._CHBOX_slave.SetValue(_cfg.get(option = 'slave'))
