@@ -73,11 +73,11 @@ def emr_access_spinner(time2spin=0):
 #================================================================
 # episode related widgets/functions
 #----------------------------------------------------------------
-def edit_episode(parent=None, episode=None):
-	ea = cEpisodeEditAreaPnl(parent = parent, id = -1)
+def edit_episode(parent=None, episode=None, single_entry=True):
+	ea = cEpisodeEditAreaPnl(parent, -1)
 	ea.data = episode
 	ea.mode = gmTools.coalesce(episode, 'new', 'edit')
-	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = True)
+	dlg = gmEditArea.cGenericEditAreaDlg2(parent, -1, edit_area = ea, single_entry = single_entry)
 	dlg.SetTitle(gmTools.coalesce(episode, _('Adding a new episode'), _('Editing an episode')))
 	if dlg.ShowModal() == wx.ID_OK:
 		return True
@@ -99,7 +99,7 @@ def manage_episodes(parent=None):
 		if gmEMRStructItems.delete_episode(episode = episode):
 			return True
 		gmDispatcher.send (
-			signal = u'statustext',
+			signal = 'statustext',
 			msg = _('Cannot delete episode.'),
 			beep = True
 		)
@@ -126,12 +126,12 @@ def manage_episodes(parent=None):
 		)
 	#-----------------------------------------
 	def refresh(lctrl):
-		epis = emr.get_episodes(order_by = u'description')
+		epis = emr.get_episodes(order_by = 'description')
 		items = [
 			[	e['description'],
-				gmTools.bool2subst(e['episode_open'], _(u'ongoing'), _(u'closed'), u'<unknown>'),
+				gmTools.bool2subst(e['episode_open'], _('ongoing'), _('closed'), '<unknown>'),
 				gmDateTime.pydt_strftime(e.best_guess_clinical_start_date, '%Y %b %d'),
-				gmTools.coalesce(e['health_issue'], u'')
+				gmTools.coalesce(e['health_issue'], '')
 			] for e in epis
 		]
 		lctrl.set_string_items(items = items)
@@ -141,7 +141,7 @@ def manage_episodes(parent=None):
 		parent = parent,
 		msg = _('\nSelect the episode you want to edit !\n'),
 		caption = _('Editing episodes ...'),
-		columns = [_(u'Episode'), _('Status'), _('Started'), _(u'Health issue')],
+		columns = [_('Episode'), _('Status'), _('Started'), _('Health issue')],
 		single_selection = True,
 		edit_callback = edit,
 		new_callback = edit,
@@ -183,7 +183,7 @@ def promote_episode_to_issue(parent=None, episode=None, emr=None):
 			]
 		)
 		use_existing = dlg.ShowModal()
-		dlg.Destroy()
+		dlg.DestroyLater()
 
 		if use_existing == wx.ID_CANCEL:
 			return
@@ -194,19 +194,19 @@ def promote_episode_to_issue(parent=None, episode=None, emr=None):
 			issue_name = episode['description']
 			while issue_name == episode['description']:
 				dlg = wx.TextEntryDialog (
-					parent = parent,
-					message = _('Enter a short descriptive name for the new health issue:'),
+					parent,
+					_('Enter a short descriptive name for the new health issue:'),
 					caption = _('Creating a new health issue ...'),
-					defaultValue = issue_name,
+					value = issue_name,
 					style = wx.OK | wx.CANCEL | wx.CENTRE
 				)
 				decision = dlg.ShowModal()
 				if decision != wx.ID_OK:
-					dlg.Destroy()
+					dlg.DestroyLater()
 					return
 				issue_name = dlg.GetValue().strip()
-				dlg.Destroy()
-				if issue_name == u'':
+				dlg.DestroyLater()
+				if issue_name == '':
 					issue_name = episode['description']
 
 			issue = emr.add_health_issue(issue_name = issue_name)
@@ -248,7 +248,7 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	# try closing possibly expired episode on target issue if any
 	db_cfg = gmCfg.cCfgSQL()
 	epi_ttl = int(db_cfg.get2 (
-		option = u'episode.ttl',
+		option = 'episode.ttl',
 		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 		bias = 'user',
 		default = 60				# 2 months
@@ -274,12 +274,12 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	# we got two open episodes at once, ask user
 	move_range = (episode.best_guess_clinical_start_date, episode.best_guess_clinical_end_date)
 	if move_range[1] is None:
-		move_range_end = u'?'
+		move_range_end = '?'
 	else:
 		move_range_end = move_range[1].strftime('%m/%y')
 	exist_range = (existing_epi.best_guess_clinical_start_date, existing_epi.best_guess_clinical_end_date)
 	if exist_range[1] is None:
-		exist_range_end = u'?'
+		exist_range_end = '?'
 	else:
 		exist_range_end = exist_range[1].strftime('%m/%y')
 	question = _(
@@ -352,8 +352,8 @@ class cEpisodeListSelectorDlg(gmListWidgets.cGenericListSelectorDlg):
 		self._LCTRL_items.set_string_items (
 			items = [ 
 				[	epi['description'], 
-					gmTools.bool2str(epi['episode_open'], _('ongoing'), u''), 
-					gmTools.coalesce(epi['health_issue'], u'')
+					gmTools.bool2str(epi['episode_open'], _('ongoing'), ''), 
+					gmTools.coalesce(epi['health_issue'], '')
 				]
 				for epi in episodes ]
 		)
@@ -378,7 +378,7 @@ class cEpisodeDescriptionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
 			queries = [
-u"""
+"""
 SELECT DISTINCT ON (description)
 	description
 		AS data,
@@ -420,81 +420,27 @@ class cEpisodeSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	gmPerson.gmCurrentPatient() changes.
 	"""
 	def __init__(self, *args, **kwargs):
-
-		ctxt = {'ctxt_pat': {'where_part': u'and pk_patient = %(pat)s', 'placeholder': u'pat'}}
-
-		mp = gmMatchProvider.cMatchProvider_SQL2 (
-			queries = [
-u"""(
-
-SELECT
-	pk_episode
-		as data,
-	description
-		as field_label,
-	coalesce (
-		description || ' - ' || health_issue,
-		description
-	) as list_label,
-	1 as rank
-from
-  	clin.v_pat_episodes
-where
-	episode_open is true and
-	description %(fragment_condition)s
-	%(ctxt_pat)s
-
-) union all (
-
-SELECT
-	pk_episode
-		as data,
-	description
-		as field_label,
-	coalesce (
-		description || _(' (closed)') || ' - ' || health_issue,
-		description || _(' (closed)')
-	) as list_label,
-	2 as rank
-from
-	clin.v_pat_episodes
-where
-	description %(fragment_condition)s and
-	episode_open is false
-	%(ctxt_pat)s
-
-)
-
-order by rank, list_label
-limit 30"""
-],
-			context = ctxt
-		)
-
 		try:
-			kwargs['patient_id']
+			self.__patient_id = int(kwargs['patient_id'])
+			self.use_current_patient = False
+			del kwargs['patient_id']
 		except KeyError:
-			kwargs['patient_id'] = None
-
-		if kwargs['patient_id'] is None:
+			self.__patient_id = None
 			self.use_current_patient = True
+
+		mp = gmEMRStructItems.cEpisodeMatchProvider()
+		if self.use_current_patient:
 			self.__register_patient_change_signals()
 			pat = gmPerson.gmCurrentPatient()
 			if pat.connected:
 				mp.set_context('pat', pat.ID)
 		else:
-			self.use_current_patient = False
-			self.__patient_id = int(kwargs['patient_id'])
 			mp.set_context('pat', self.__patient_id)
 
-		del kwargs['patient_id']
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
 
-		gmPhraseWheel.cPhraseWheel.__init__ (
-			self,
-			*args,
-			**kwargs
-		)
 		self.matcher = mp
+
 	#--------------------------------------------------------
 	# external API
 	#--------------------------------------------------------
@@ -504,16 +450,18 @@ limit 30"""
 		self.__patient_id = int(patient_id)
 		self.set_context('pat', self.__patient_id)
 		return True
+
 	#--------------------------------------------------------
 	def GetData(self, can_create=False, as_instance=False, is_open=False):
 		self.__is_open_for_create_data = is_open		# used (only) in _create_data()
 		return gmPhraseWheel.cPhraseWheel.GetData(self, can_create = can_create, as_instance = as_instance)
+
 	#--------------------------------------------------------
 	def _create_data(self):
 
 		epi_name = self.GetValue().strip()
-		if epi_name == u'':
-			gmDispatcher.send(signal = u'statustext', msg = _('Cannot create episode without name.'), beep = True)
+		if epi_name == '':
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot create episode without name.'), beep = True)
 			_log.debug('cannot create episode without name')
 			return
 
@@ -531,21 +479,25 @@ limit 30"""
 				value = epi_name,
 				data = epi['pk_episode']
 			)
+
 	#--------------------------------------------------------
 	def _data2instance(self):
 		return gmEMRStructItems.cEpisode(aPK_obj = self.GetData())
+
 	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
 	def __register_patient_change_signals(self):
-		gmDispatcher.connect(self._pre_patient_unselection, u'pre_patient_unselection')
-		gmDispatcher.connect(self._post_patient_selection, u'post_patient_selection')
+		gmDispatcher.connect(self._pre_patient_unselection, 'pre_patient_unselection')
+		gmDispatcher.connect(self._post_patient_selection, 'post_patient_selection')
+
 	#--------------------------------------------------------
 	def _pre_patient_unselection(self):
 		self.__patient_id = None
 		self.unset_context('pat')
 		self.SetData()
 		return True
+
 	#--------------------------------------------------------
 	def _post_patient_selection(self):
 		if self.use_current_patient:
@@ -661,7 +613,7 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 		self._TCTRL_patient.SetValue(ident.get_description_gender())
 		self._PRW_issue.SetText()
 		self._PRW_description.SetText()
-		self._TCTRL_status.SetValue(u'')
+		self._TCTRL_status.SetValue('')
 		self._PRW_certainty.SetText()
 		self._CHBOX_closed.SetValue(False)
 		self._PRW_codes.SetText()
@@ -684,7 +636,7 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 			data = self.data['description']
 		)
 
-		self._TCTRL_status.SetValue(gmTools.coalesce(self.data['summary'], u''))
+		self._TCTRL_status.SetValue(gmTools.coalesce(self.data['summary'], ''))
 
 		if self.data['diagnostic_certainty_classification'] is not None:
 			self._PRW_certainty.SetData(data = self.data['diagnostic_certainty_classification'])
@@ -706,17 +658,18 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 #================================================================
 # health issue related widgets/functions
 #----------------------------------------------------------------
-def edit_health_issue(parent=None, issue=None):
-	ea = cHealthIssueEditAreaPnl(parent = parent, id = -1)
+def edit_health_issue(parent=None, issue=None, single_entry=False):
+	ea = cHealthIssueEditAreaPnl(parent, -1)
 	ea.data = issue
 	ea.mode = gmTools.coalesce(issue, 'new', 'edit')
-	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = (issue is not None))
+	dlg = gmEditArea.cGenericEditAreaDlg2(parent, -1, edit_area = ea, single_entry = single_entry)
 	dlg.SetTitle(gmTools.coalesce(issue, _('Adding a new health issue'), _('Editing a health issue')))
 	if dlg.ShowModal() == wx.ID_OK:
-		dlg.Destroy()
+		dlg.DestroyLater()
 		return True
-	dlg.Destroy()
+	dlg.DestroyLater()
 	return False
+
 #----------------------------------------------------------------
 def select_health_issues(parent=None, emr=None):
 
@@ -730,7 +683,7 @@ def select_health_issues(parent=None, emr=None):
 		if gmEMRStructItems.delete_health_issue(health_issue = issue):
 			return True
 		gmDispatcher.send (
-			signal = u'statustext',
+			signal = 'statustext',
 			msg = _('Cannot delete health issue.'),
 			beep = True
 		)
@@ -759,11 +712,11 @@ def select_health_issues(parent=None, emr=None):
 		issues = emr.get_health_issues()
 		items = [
 			[
-				gmTools.bool2subst(i['is_confidential'], _('CONFIDENTIAL'), u'', u''),
+				gmTools.bool2subst(i['is_confidential'], _('CONFIDENTIAL'), '', ''),
 				i['description'],
-				gmTools.bool2subst(i['clinically_relevant'], _('relevant'), u'', u''),
-				gmTools.bool2subst(i['is_active'], _('active'), u'', u''),
-				gmTools.bool2subst(i['is_cause_of_death'], _('fatal'), u'', u'')
+				gmTools.bool2subst(i['clinically_relevant'], _('relevant'), '', ''),
+				gmTools.bool2subst(i['is_active'], _('active'), '', ''),
+				gmTools.bool2subst(i['is_cause_of_death'], _('fatal'), '', '')
 			] for i in issues
 		]
 		lctrl.set_string_items(items = items)
@@ -773,7 +726,7 @@ def select_health_issues(parent=None, emr=None):
 		parent = parent,
 		msg = _('\nSelect the health issues !\n'),
 		caption = _('Showing health issues ...'),
-		columns = [u'', _('Health issue'), u'', u'', u''],
+		columns = ['', _('Health issue'), '', '', ''],
 		single_selection = False,
 		edit_callback = edit,
 		new_callback = edit,
@@ -793,25 +746,26 @@ class cIssueListSelectorDlg(gmListWidgets.cGenericListSelectorDlg):
 		gmListWidgets.cGenericListSelectorDlg.__init__(self, *args, **kwargs)
 
 		self.SetTitle(_('Select the health issues you are interested in ...'))
-		self._LCTRL_items.set_columns([u'', _('Health Issue'), u'', u'', u''])
+		self._LCTRL_items.set_columns(['', _('Health Issue'), '', '', ''])
 
 		for issue in issues:
 			if issue['is_confidential']:
-				row_num = self._LCTRL_items.InsertStringItem(sys.maxint, label = _('confidential'))
-				self._LCTRL_items.SetItemTextColour(row_num, col=wx.NamedColour('RED'))
+				row_num = self._LCTRL_items.InsertItem(sys.maxsize, label = _('confidential'))
+				self._LCTRL_items.SetItemTextColour(row_num, wx.Colour('RED'))
 			else:
-				row_num = self._LCTRL_items.InsertStringItem(sys.maxint, label = u'')
+				row_num = self._LCTRL_items.InsertItem(sys.maxsize, label = '')
 
-			self._LCTRL_items.SetStringItem(index = row_num, col = 1, label = issue['description'])
+			self._LCTRL_items.SetItem(index = row_num, column = 1, label = issue['description'])
 			if issue['clinically_relevant']:
-				self._LCTRL_items.SetStringItem(index = row_num, col = 2, label = _('relevant'))
+				self._LCTRL_items.SetItem(index = row_num, column = 2, label = _('relevant'))
 			if issue['is_active']:
-				self._LCTRL_items.SetStringItem(index = row_num, col = 3, label = _('active'))
+				self._LCTRL_items.SetItem(index = row_num, column = 3, label = _('active'))
 			if issue['is_cause_of_death']:
-				self._LCTRL_items.SetStringItem(index = row_num, col = 4, label = _('fatal'))
+				self._LCTRL_items.SetItem(index = row_num, column = 4, label = _('fatal'))
 
 		self._LCTRL_items.set_column_widths()
 		self._LCTRL_items.set_data(data = issues)
+
 #----------------------------------------------------------------
 class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let the user select a health issue.
@@ -830,11 +784,11 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""
 	def __init__(self, *args, **kwargs):
 
-		ctxt = {'ctxt_pat': {'where_part': u'pk_patient=%(pat)s', 'placeholder': u'pat'}}
+		ctxt = {'ctxt_pat': {'where_part': 'pk_patient=%(pat)s', 'placeholder': 'pat'}}
 
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
 			# FIXME: consider clin.health_issue.clinically_relevant
-			queries = [u"""
+			queries = ["""
 				SELECT
 					data,
 					field_label,
@@ -905,8 +859,8 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	#--------------------------------------------------------
 	def _create_data(self):
 		issue_name = self.GetValue().strip()
-		if issue_name == u'':
-			gmDispatcher.send(signal = u'statustext', msg = _('Cannot create health issue without name.'), beep = True)
+		if issue_name == '':
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot create health issue without name.'), beep = True)
 			_log.debug('cannot create health issue without name')
 			return
 
@@ -954,8 +908,8 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	# internal API
 	#--------------------------------------------------------
 	def __register_patient_change_signals(self):
-		gmDispatcher.connect(self._pre_patient_unselection, u'pre_patient_unselection')
-		gmDispatcher.connect(self._post_patient_selection, u'post_patient_selection')
+		gmDispatcher.connect(self._pre_patient_unselection, 'pre_patient_unselection')
+		gmDispatcher.connect(self._post_patient_selection, 'post_patient_selection')
 	#--------------------------------------------------------
 	def _pre_patient_unselection(self):
 		return True
@@ -1018,13 +972,13 @@ class cHealthIssueEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgHealthIssueEd
 
 		# FIXME: include more sources: coding systems/other database columns
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
-			queries = [u"SELECT DISTINCT ON (description) description, description FROM clin.health_issue WHERE description %(fragment_condition)s LIMIT 50"]
+			queries = ["SELECT DISTINCT ON (description) description, description FROM clin.health_issue WHERE description %(fragment_condition)s LIMIT 50"]
 		)
 		mp.setThresholds(1, 3, 5)
 		self._PRW_condition.matcher = mp
 
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
-			queries = [u"""
+			queries = ["""
 SELECT DISTINCT ON (grouping) grouping, grouping from (
 
 	SELECT rank, grouping from ((
@@ -1085,13 +1039,14 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 
 		# FIXME: sanity check age/year diagnosed
 		age_noted = self._PRW_age_noted.GetValue().strip()
-		if age_noted != u'':
+		if age_noted != '':
 			if gmDateTime.str2interval(str_interval = age_noted) is None:
 				self._PRW_age_noted.display_as_valid(False)
 				self._PRW_age_noted.SetFocus()
 				return False
 		self._PRW_age_noted.display_as_valid(True)
 		return True
+
 	#----------------------------------------------------------------
 	def _save_as_new(self):
 		pat = gmPerson.gmCurrentPatient()
@@ -1099,11 +1054,11 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 
 		issue = emr.add_health_issue(issue_name = self._PRW_condition.GetValue().strip())
 
-		side = u''
+		side = ''
 		if self._ChBOX_left.GetValue():
-			side += u's'
+			side += 's'
 		if self._ChBOX_right.GetValue():
-			side += u'd'
+			side += 'd'
 		issue['laterality'] = side
 
 		issue['summary'] = self._TCTRL_status.GetValue().strip()
@@ -1129,11 +1084,11 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 
 		self.data['description'] = self._PRW_condition.GetValue().strip()
 
-		side = u''
+		side = ''
 		if self._ChBOX_left.GetValue():
-			side += u's'
+			side += 's'
 		if self._ChBOX_right.GetValue():
-			side += u'd'
+			side += 'd'
 		self.data['laterality'] = side
 
 		self.data['summary'] = self._TCTRL_status.GetValue().strip()
@@ -1161,7 +1116,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		self._on_leave_codes()
 		self._PRW_certainty.SetText()
 		self._PRW_grouping.SetText()
-		self._TCTRL_status.SetValue(u'')
+		self._TCTRL_status.SetValue('')
 		self._PRW_age_noted.SetText()
 		self._PRW_year_noted.SetText()
 		self._ChBOX_active.SetValue(1)
@@ -1191,8 +1146,8 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 
 		if self.data['diagnostic_certainty_classification'] is not None:
 			self._PRW_certainty.SetData(data = self.data['diagnostic_certainty_classification'])
-		self._PRW_grouping.SetText(gmTools.coalesce(self.data['grouping'], u''))
-		self._TCTRL_status.SetValue(gmTools.coalesce(self.data['summary'], u''))
+		self._PRW_grouping.SetText(gmTools.coalesce(self.data['grouping'], ''))
+		self._TCTRL_status.SetValue(gmTools.coalesce(self.data['summary'], ''))
 
 		if self.data['age_noted'] is None:
 			self._PRW_age_noted.SetText()
@@ -1220,7 +1175,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		if not self._PRW_codes.IsModified():
 			return True
 
-		self._TCTRL_code_details.SetValue(u'- ' + u'\n- '.join([ c['list_label'] for c in self._PRW_codes.GetData() ]))
+		self._TCTRL_code_details.SetValue('- ' + '\n- '.join([ c['list_label'] for c in self._PRW_codes.GetData() ]))
 	#--------------------------------------------------------
 	def _on_leave_age_noted(self, *args, **kwargs):
 
@@ -1229,13 +1184,13 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 
 		age_str = self._PRW_age_noted.GetValue().strip()
 
-		if age_str == u'':
+		if age_str == '':
 			return True
 
 		issue_age = gmDateTime.str2interval(str_interval = age_str)
 
 		if issue_age is None:
-			self.status_message = _('Cannot parse [%s] into valid interval.') % age_str
+			self.StatusText = _('Cannot parse [%s] into valid interval.') % age_str
 			self._PRW_age_noted.display_as_valid(False)
 			return True
 
@@ -1243,7 +1198,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		if pat['dob'] is not None:
 			max_issue_age = pydt.datetime.now(tz=pat['dob'].tzinfo) - pat['dob']
 			if issue_age >= max_issue_age:
-				self.status_message = _('Health issue cannot have been noted at age %s. Patient is only %s old.') % (issue_age, pat.get_medical_age())
+				self.StatusText = _('Health issue cannot have been noted at age %s. Patient is only %s old.') % (issue_age, pat.get_medical_age())
 				self._PRW_age_noted.display_as_valid(False)
 				return True
 
@@ -1267,7 +1222,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		year_noted = self._PRW_year_noted.GetData()
 
 		if year_noted is None:
-			if self._PRW_year_noted.GetValue().strip() == u'':
+			if self._PRW_year_noted.GetValue().strip() == '':
 				self._PRW_year_noted.display_as_valid(True)
 				return True
 			self._PRW_year_noted.display_as_valid(False)
@@ -1276,7 +1231,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		year_noted = year_noted.get_pydt()
 
 		if year_noted >= pydt.datetime.now(tz = year_noted.tzinfo):
-			self.status_message = _('Condition diagnosed in the future.')
+			self.StatusText = _('Condition diagnosed in the future.')
 			self._PRW_year_noted.display_as_valid(False)
 			return True
 
@@ -1291,12 +1246,13 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 		return True
 	#--------------------------------------------------------
 	def _on_modified_age_noted(self, *args, **kwargs):
-		wx.CallAfter(self._PRW_year_noted.SetText, u'', None, True)
+		wx.CallAfter(self._PRW_year_noted.SetText, '', None, True)
 		return True
 	#--------------------------------------------------------
 	def _on_modified_year_noted(self, *args, **kwargs):
-		wx.CallAfter(self._PRW_age_noted.SetText, u'', None, True)
+		wx.CallAfter(self._PRW_age_noted.SetText, '', None, True)
 		return True
+
 #================================================================
 # diagnostic certainty related widgets/functions
 #----------------------------------------------------------------
@@ -1310,16 +1266,16 @@ class cDiagnosticCertaintyClassificationPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
 		mp = gmMatchProvider.cMatchProvider_FixedList (
 			aSeq = [
-				{'data': u'A', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'A'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'A'), 'weight': 1},
-				{'data': u'B', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'B'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'B'), 'weight': 1},
-				{'data': u'C', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'C'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'C'), 'weight': 1},
-				{'data': u'D', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'D'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str(u'D'), 'weight': 1}
+				{'data': 'A', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str('A'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str('A'), 'weight': 1},
+				{'data': 'B', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str('B'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str('B'), 'weight': 1},
+				{'data': 'C', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str('C'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str('C'), 'weight': 1},
+				{'data': 'D', 'list_label': gmEMRStructItems.diagnostic_certainty_classification2str('D'), 'field_label': gmEMRStructItems.diagnostic_certainty_classification2str('D'), 'weight': 1}
 			]
 		)
 		mp.setThresholds(1, 2, 4)
 		self.matcher = mp
 
-		self.SetToolTipString(_(
+		self.SetToolTip(_(
 			"The diagnostic classification or grading of this assessment.\n"
 			"\n"
 			"This documents how certain one is about this being a true diagnosis."
@@ -1356,11 +1312,12 @@ if __name__ == '__main__':
 							size=wx.Size(600, 400),
 							style=wx.DEFAULT_FRAME_STYLE | wx.NO_FULL_REPAINT_ON_RESIZE
 						)
-				filemenu= wx.Menu()
+				filemenu = wx.Menu()
 				filemenu.AppendSeparator()
-				filemenu.Append(ID_EXIT,"E&xit"," Terminate test application")
+				item = filemenu.Append(ID_EXIT, "E&xit"," Terminate test application")
+				self.Bind(wx.EVT_MENU, self.OnCloseWindow, item)
 
-				# Creating the menubar.	
+				# Creating the menubar.
 				menuBar = wx.MenuBar()
 				menuBar.Append(filemenu,"&File")
 
@@ -1369,9 +1326,6 @@ if __name__ == '__main__':
 				txt = wx.StaticText( frame, -1, _("Select desired test option from the 'File' menu"),
 				wx.DefaultPosition, wx.DefaultSize, 0 )
 
-				# event handlers
-				wx.EVT_MENU(frame, ID_EXIT, self.OnCloseWindow)
-
 				# patient EMR
 				self.__pat = gmPerson.gmCurrentPatient()
 
@@ -1401,10 +1355,13 @@ if __name__ == '__main__':
 
 	#----------------------------------------------------------------
 	def test_episode_selection_prw():
-		app = wx.PyWidgetTester(size = (400, 40))
-		app.SetWidget(cEpisodeSelectionPhraseWheel, id=-1, size=(180,20), pos=(10,20))
+		frame = wx.Frame()
+		wx.GetApp().SetTopWindow(frame)
+		prw = cEpisodeSelectionPhraseWheel(frame)
+		#app.SetWidget()
 #		app.SetWidget(cEpisodeSelectionPhraseWheel, id=-1, size=(350,20), pos=(10,20), patient_id=pat.ID)
-		app.MainLoop()
+		frame.Show(True)
+		wx.GetApp().MainLoop()
 
 	#----------------------------------------------------------------
 	def test_health_issue_edit_area_dlg():
@@ -1419,22 +1376,20 @@ if __name__ == '__main__':
 
 	#================================================================
 
+	branch = gmPraxis.get_praxis_branches()[0]
+	prax = gmPraxis.gmCurrentPraxisBranch(branch)
+	print(prax)
+
+	#app = wx.PyWidgetTester(size = (400, 40))
+	app = wx.App()#size = (400, 40))
+
 	# obtain patient
 	pat = gmPersonSearch.ask_for_patient()
 	if pat is None:
-		print "No patient. Exiting gracefully..."
+		print("No patient. Exiting gracefully...")
 		sys.exit(0)
 	gmPatSearchWidgets.set_active_patient(patient=pat)
 
-#	try:
-		# lauch emr dialogs test application
-#		app = testapp(0)
-#		app.MainLoop()
-#	except Exception:
-#		_log.exception("unhandled exception caught !")
-		# but re-raise them
-#		raise
-
 	#test_epsiode_edit_area_pnl()
 	#test_episode_edit_area_dialog()
 	#test_health_issue_edit_area_dlg()
