@@ -12,6 +12,8 @@ import os
 import logging
 import sys
 import io
+import time
+import datetime as pyDT
 
 
 import wx
@@ -81,7 +83,7 @@ class c2ButtonQuestionDlg(wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg):
 
 		wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg.__init__(self, *args, **kwargs)
 
-		self.SetTitle(title = caption)
+		self.SetTitle(title = gmTools.decorate_window_title(caption))
 		self._LBL_question.SetLabel(label = question)
 
 		if not show_checkbox:
@@ -90,12 +92,12 @@ class c2ButtonQuestionDlg(wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg):
 			if checkbox_msg is not None:
 				self._CHBOX_dont_ask_again.SetLabel(checkbox_msg)
 			if checkbox_tooltip is not None:
-				self._CHBOX_dont_ask_again.SetToolTipString(checkbox_tooltip)
+				self._CHBOX_dont_ask_again.SetToolTip(checkbox_tooltip)
 
 		buttons = [self._BTN_1, self._BTN_2]
 		for idx in range(len(button_defs)):
 			buttons[idx].SetLabel(label = button_defs[idx]['label'])
-			buttons[idx].SetToolTipString(button_defs[idx]['tooltip'])
+			buttons[idx].SetToolTip(button_defs[idx]['tooltip'])
 			try:
 				if button_defs[idx]['default'] is True:
 					buttons[idx].SetDefault()
@@ -128,7 +130,15 @@ from Gnumed.wxGladeWidgets import wxg3ButtonQuestionDlg
 class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 
 	def __init__(self, *args, **kwargs):
+		"""Initialize.
 
+	button_defs = [
+		# tooltip and default are optional
+		{'label': _(''), 'tooltip': _(''), 'default': True/False},
+		{'label': _(''), 'tooltip': _(''), 'default': True/False},
+		{'label': _(''), 'tooltip': _(''), 'default': True/False}
+	]
+		"""
 		caption = kwargs['caption']
 		question = kwargs['question']
 		button_defs = kwargs['button_defs'][:3]
@@ -156,7 +166,7 @@ class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 
 		wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg.__init__(self, *args, **kwargs)
 
-		self.SetTitle(title = caption)
+		self.SetTitle(title = gmTools.decorate_window_title(caption))
 		self._LBL_question.SetLabel(label = question)
 
 		if not show_checkbox:
@@ -165,12 +175,15 @@ class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 			if checkbox_msg is not None:
 				self._CHBOX_dont_ask_again.SetLabel(checkbox_msg)
 			if checkbox_tooltip is not None:
-				self._CHBOX_dont_ask_again.SetToolTipString(checkbox_tooltip)
+				self._CHBOX_dont_ask_again.SetToolTip(checkbox_tooltip)
 
 		buttons = [self._BTN_1, self._BTN_2, self._BTN_3]
 		for idx in range(len(button_defs)):
 			buttons[idx].SetLabel(label = button_defs[idx]['label'])
-			buttons[idx].SetToolTipString(button_defs[idx]['tooltip'])
+			try:
+				buttons[idx].SetToolTip(button_defs[idx]['tooltip'])
+			except KeyError:
+				pass
 			try:
 				if button_defs[idx]['default'] is True:
 					buttons[idx].SetDefault()
@@ -182,6 +195,7 @@ class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 	#--------------------------------------------------------
 	def checkbox_is_checked(self):
 		return self._CHBOX_dont_ask_again.IsChecked()
+
 	#--------------------------------------------------------
 	# event handlers
 	#--------------------------------------------------------
@@ -190,6 +204,7 @@ class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 			self.EndModal(wx.ID_YES)
 		else:
 			self.Close()
+
 	#--------------------------------------------------------
 	def _on_BTN_2_pressed(self, evt):
 		if self.IsModal():
@@ -232,7 +247,7 @@ class cMultilineTextEntryDlg(wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg):
 		wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg.__init__(self, *args, **kwargs)
 
 		if title is not None:
-			self.SetTitle(title)
+			self.SetTitle(gmTools.decorate_window_title(title))
 
 		if self.original_text is not None:
 			self._TCTRL_text.SetValue(self.original_text)
@@ -281,7 +296,7 @@ class cMultilineTextEntryDlg(wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg):
 			self.Close()
 	#--------------------------------------------------------
 	def _on_clear_button_pressed(self, evt):
-		self._TCTRL_text.SetValue(u'')
+		self._TCTRL_text.SetValue('')
 	#--------------------------------------------------------
 	def _on_restore_button_pressed(self, evt):
 		if self.original_text is not None:
@@ -326,8 +341,8 @@ def clipboard2file(check_for_filename=False):
 				return clipboard_text_content
 			except IOError:
 				_log.exception('clipboard does not seem to hold filename: %s', clipboard_text_content)
-		fname = gmTools.get_unique_filename(prefix = u'gm-clipboard-', suffix = u'.txt')
-		target_file = io.open(fname, mode = u'wt', encoding = u'utf8')
+		fname = gmTools.get_unique_filename(prefix = 'gm-clipboard-', suffix = '.txt')
+		target_file = io.open(fname, mode = 'wt', encoding = 'utf8')
 		target_file.write(clipboard_text_content)
 		target_file.close()
 		return fname
@@ -335,7 +350,7 @@ def clipboard2file(check_for_filename=False):
 	data_obj = wx.BitmapDataObject()
 	got_it = wx.TheClipboard.GetData(data_obj)
 	if got_it:
-		fname = gmTools.get_unique_filename(prefix = u'gm-clipboard-', suffix = u'.png')
+		fname = gmTools.get_unique_filename(prefix = 'gm-clipboard-', suffix = '.png')
 		bmp = data_obj.Bitmap.SaveFile(fname, wx.BITMAP_TYPE_PNG)
 		wx.TheClipboard.Close()
 		return fname
@@ -359,7 +374,7 @@ def text2clipboard(text=None, announce_result=False):
 
 #-------------------------------------------------------------------------
 def file2clipboard(filename=None, announce_result=False):
-	f = io.open(filename, mode = u'rt', encoding = u'utf8')
+	f = io.open(filename, mode = 'rt', encoding = 'utf8')
 	result = text2clipboard(text = f.read(), announce_result = False)
 	f.close()
 	if announce_result:
@@ -384,14 +399,11 @@ class cFileDropTarget(wx.FileDropTarget):
 	#-----------------------------------------------
 	def __init__(self, target=None, on_drop_callback=None):
 		if target is not None:
-			try:
-				on_drop_callback = getattr(target, '_drop_target_consume_filenames')
-			except AttributeError:
-				_log.exception('[%s._drop_target_consume_filenames()] does not exist, cannot set as drop target callback', target)
-				raise
+			on_drop_callback = getattr(target, '_drop_target_consume_filenames')
 		if not callable(on_drop_callback):
 			_log.error('[%s] not callable, cannot set as drop target callback', on_drop_callback)
 			raise AttributeError('[%s] not callable, cannot set as drop target callback', on_drop_callback)
+
 		self._on_drop_callback = on_drop_callback
 		wx.FileDropTarget.__init__(self)
 		_log.debug('setting up [%s] as file drop target', self._on_drop_callback)
@@ -415,7 +427,7 @@ def file2scaled_image(filename=None, height=100):
 #			current_height = 1
 		rescaled_width = (float(current_width) / current_height) * rescaled_height
 		img_data.Rescale(rescaled_width, rescaled_height, quality = wx.IMAGE_QUALITY_HIGH)		# w, h
-		bitmap = wx.BitmapFromImage(img_data)
+		bitmap = wx.Bitmap(img_data)
 		del img_data
 	except Exception:
 		_log.exception('cannot load image from [%s]', filename)
@@ -424,6 +436,148 @@ def file2scaled_image(filename=None, height=100):
 		return None
 	return bitmap
 
+# ========================================================================
+def save_screenshot_to_file(filename=None, widget=None, settle_time=None):
+	"""Take screenshot of widget.
+
+	<settle_time> in milliseconds
+	"""
+	assert (isinstance(widget, wx.Window)), '<widget> must be (sub)class of wx.Window'
+
+	if filename is None:
+		filename = gmTools.get_unique_filename (
+			prefix = 'gm-screenshot-%s-' % pyDT.datetime.now().strftime('%Y-%m-%d_%H-%M-%S'),
+			suffix = '.png'
+			# for testing:
+			#,tmp_dir = os.path.join(gmTools.gmPaths().home_dir, 'gnumed')
+		)
+	else:
+		filename = gmTools.fname_sanitize(filename)
+
+	_log.debug('filename: %s', filename)
+	_log.debug('widget: %s', widget)
+	_log.debug('display size: %s', wx.DisplaySize())
+
+	# let it settle a bit for, say, tooltips
+	if settle_time is not None:
+		for wait_slice in range(int(settle_time // 100)):
+			wx.SafeYield()
+			time.sleep(0.1)
+
+	widget_rect_on_screen = widget.GetScreenRect()
+	client_area_origin_on_screen = widget.ClientToScreen((0, 0))
+	widget_rect_local = widget.GetRect()
+	widget_rect_client_area = widget.GetClientRect()
+	client_area_origin_local = widget.GetClientAreaOrigin()
+
+	_log.debug('widget.GetScreenRect(): %s', widget_rect_on_screen)
+	_log.debug('widget.ClientToScreen(0, 0): %s', client_area_origin_on_screen)
+	_log.debug('widget.GetRect(): %s', widget_rect_local)
+	_log.debug('widget.GetClientRect(): %s', widget_rect_client_area)
+	_log.debug('widget.GetClientAreaOrigin(): %s', client_area_origin_local)
+
+	width2snap = widget_rect_local.width
+	height2snap = widget_rect_local.height
+	border_x = client_area_origin_on_screen.x - widget_rect_local.x
+	x2snap_from = 0 - border_x
+	title_and_menu_height = client_area_origin_on_screen.y - widget_rect_on_screen.y
+	y2snap_from = 0 - title_and_menu_height
+
+	# those are the correct dimensions but we don't get to
+	# *see* the window decorations on a WindowDC or ClientDC :-(
+	# (and a screendc doesn't work either)
+	_log.debug('left (x) border: %s', border_x)
+	_log.debug('top (y) border: %s', title_and_menu_height)
+	_log.debug('x2snap_from: %s', x2snap_from)
+	_log.debug('y2snap_from: %s', y2snap_from)
+	_log.debug('width2snap: %s', width2snap)
+	_log.debug('height2snap: %s', height2snap)
+
+	# WindowDC includes decorations, supposedly, but Windows only
+	window_dc = wx.WindowDC(widget)
+	wxbmp = __snapshot_to_bitmap (
+		source_dc = window_dc,
+		x2snap_from = x2snap_from,
+		y2snap_from = y2snap_from,
+		width2snap = width2snap,
+		height2snap = height2snap
+	)
+	window_dc.Destroy()
+	del window_dc
+	wxbmp.SaveFile(filename, wx.BITMAP_TYPE_PNG)
+	del wxbmp
+
+	x2snap_on_screen = widget_rect_on_screen.x
+	y2snap_on_screen = widget_rect_on_screen.y			# adjust for menu/title ?
+	sane_x2snap_on_screen = max(0, x2snap_on_screen)
+	sane_y2snap_on_screen = max(0, y2snap_on_screen)
+
+	_log.debug('x2snap_on_screen: %s', x2snap_on_screen)
+	_log.debug('y2snap_on_screen: %s', y2snap_on_screen)
+	_log.debug('sane x2snap_on_screen: %s', sane_x2snap_on_screen)
+	_log.debug('sane x2snap_on_screen: %s', sane_y2snap_on_screen)
+
+	screen_dc = wx.ScreenDC()
+	# not implemented:
+	#wxbmp = screen_dc.GetAsBitmap()		# can use subrect=...
+	wxbmp = __snapshot_to_bitmap (
+		source_dc = screen_dc,
+		x2snap_from = sane_x2snap_on_screen,
+		y2snap_from = sane_y2snap_on_screen,
+		width2snap = width2snap,
+		height2snap = height2snap
+	)
+	screen_dc.Destroy()
+	del screen_dc
+	wxbmp.SaveFile(filename + '.screendc.png', wx.BITMAP_TYPE_PNG)
+	del wxbmp
+
+	# ClientDC does not include decorations, only client area
+	#client_dc = wx.ClientDC(widget)
+	#wxbmp = __snapshot_to_bitmap (
+	#	source_dc = client_dc,
+	#	x2snap_from = x2snap_from,
+	#	y2snap_from = y2snap_from,
+	#	width2snap = width2snap,
+	#	height2snap = height2snap
+	#)
+	#client_dc.Destroy()
+	#del client_dc
+	#wxbmp.SaveFile(filename + '.clientdc.png', wx.BITMAP_TYPE_PNG)
+	#del wxbmp
+
+	# adjust for window decoration on Linux
+	#if sys.platform == 'linux':
+	# If the widget has a menu bar, remove that from the title bar height.
+	#if hasattr(widget, 'GetMenuBar'):
+	#	if widget.GetMenuBar():
+	#		title_bar_height /= 2
+	#		print('title bar height:', title_bar_height)
+	#width2snap += (border_width * 2)
+	#height2snap += title_bar_height + border_width
+
+	gmDispatcher.send(signal = 'statustext', msg = _('Saved screenshot to file [%s].') % filename)
+	return filename
+
+#-------------------------------------------------------------------------
+def __snapshot_to_bitmap(source_dc=None, x2snap_from=0, y2snap_from=0, width2snap=1, height2snap=1):
+	_log.debug('taking screenshot from %sx%s for %sx%s on [%s]', x2snap_from, y2snap_from, width2snap, height2snap, source_dc)
+	target_dc = wx.MemoryDC()
+	_log.debug('target DC: %s', target_dc)
+	wxbmp = wx.Bitmap(width2snap, height2snap)
+	target_dc.SelectObject(wxbmp)
+	target_dc.Clear()						# wipe anything that might have been there in memory ?	taken from wxWidgets source
+	target_dc.Blit (						# copy into this memory DC ...
+		0, 0,								# ... to here in the memory DC (= target) ...
+		width2snap, height2snap,			# ... that much ...
+		source_dc,							# ... from the source DC ...
+		x2snap_from, y2snap_from			# ... starting here
+	)
+	target_dc.SelectObject(wx.NullBitmap)	# disassociate wxbmp so it can safely be handled further
+	target_dc.Destroy()						# destroy C++ object
+	del target_dc
+	return wxbmp
+
 # ========================================================================
 def gm_show_error(aMessage=None, aTitle = None, error=None, title=None):
 
@@ -432,20 +586,18 @@ def gm_show_error(aMessage=None, aTitle = None, error=None, title=None):
 	if error is None:
 		error = _('programmer forgot to specify error message')
 	error += _("\n\nPlease consult the error log for all the gory details !")
-
 	if title is None:
 		title = aTitle
 	if title is None:
 		title = _('generic error message')
-
 	dlg = wx.MessageDialog (
 		parent = None,
 		message = error,
-		caption = title,
+		caption = gmTools.decorate_window_title(title),
 		style = wx.OK | wx.ICON_ERROR | wx.STAY_ON_TOP
 	)
 	dlg.ShowModal()
-	dlg.Destroy()
+	dlg.DestroyLater()
 	return True
 
 #-------------------------------------------------------------------------
@@ -455,38 +607,35 @@ def gm_show_info(aMessage=None, aTitle=None, info=None, title=None):
 		info = aMessage
 	if info is None:
 		info = _('programmer forgot to specify info message')
-
 	if title is None:
 		title = aTitle
 	if title is None:
 		title = _('generic info message')
-
 	dlg = wx.MessageDialog (
 		parent = None,
 		message = info,
-		caption = title,
+		caption = gmTools.decorate_window_title(title),
 		style = wx.OK | wx.ICON_INFORMATION | wx.STAY_ON_TOP
 	)
 	dlg.ShowModal()
-	dlg.Destroy()
+	dlg.DestroyLater()
 	return True
 
 #-------------------------------------------------------------------------
 def gm_show_warning(aMessage=None, aTitle=None):
 	if aMessage is None:
 		aMessage = _('programmer forgot to specify warning')
-
 	if aTitle is None:
 		aTitle = _('generic warning message')
 
 	dlg = wx.MessageDialog (
 		parent = None,
 		message = aMessage,
-		caption = aTitle,
+		caption = gmTools.decorate_window_title(aTitle),
 		style = wx.OK | wx.ICON_EXCLAMATION | wx.STAY_ON_TOP
 	)
 	dlg.ShowModal()
-	dlg.Destroy()
+	dlg.DestroyLater()
 	return True
 
 #-------------------------------------------------------------------------
@@ -500,10 +649,11 @@ def gm_show_question(aMessage='programmer forgot to specify question', aTitle='g
 		question = aMessage
 	if title is None:
 		title = aTitle
+	title = gmTools.decorate_window_title(title)
 
 	dlg = wx.MessageDialog(None, question, title, style)
 	btn_pressed = dlg.ShowModal()
-	dlg.Destroy()
+	dlg.DestroyLater()
 
 	if btn_pressed == wx.ID_YES:
 		return True
@@ -529,13 +679,13 @@ if __name__ == '__main__':
 	def test_scale_img():
 		app = wx.App()
 		img = file2scaled_image(filename = sys.argv[2])
-		print img
-		print img.Height
-		print img.Width
+		print(img)
+		print(img.Height)
+		print(img.Width)
 	#------------------------------------------------------------------
 	def test_sql_logic_prw():
 		app = wx.PyWidgetTester(size = (200, 50))
-		prw = cThreeValuedLogicPhraseWheel(parent = app.frame, id = -1)
+		prw = cThreeValuedLogicPhraseWheel(app.frame, -1)
 		app.frame.Show(True)
 		app.MainLoop()
 
@@ -545,12 +695,12 @@ if __name__ == '__main__':
 		app = wx.PyWidgetTester(size = (200, 50))
 		result = clipboard2file()
 		if result is False:
-			print "problem opening clipboard"
+			print("problem opening clipboard")
 			return
 		if result is None:
-			print "no data in clipboard"
+			print("no data in clipboard")
 			return
-		print "file:", result
+		print("file:", result)
 	#------------------------------------------------------------------
 	#test_scale_img()
 	#test_sql_logic_prw()
