@@ -43,8 +43,8 @@ def create_new_person(parent=None, activate=False):
 
 	if activate:			# meaning we will switch away from the current patient if any
 		msg = _(
-			u'Before creating a new person review the encounter details\n'
-			u'of the patient you just worked on:\n'
+			'Before creating a new person review the encounter details\n'
+			'of the patient you just worked on:\n'
 		)
 		gmEncounterWidgets.sanity_check_encounter_of_active_patient(parent = parent, msg = msg)
 
@@ -53,30 +53,30 @@ def create_new_person(parent=None, activate=False):
 	dbcfg = gmCfg.cCfgSQL()
 
 	def_region = dbcfg.get2 (
-		option = u'person.create.default_region',
+		option = 'person.create.default_region',
 		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
-		bias = u'user'
+		bias = 'user'
 	)
 	def_country = None
 
 	if def_region is None:
 		def_country = dbcfg.get2 (
-			option = u'person.create.default_country',
+			option = 'person.create.default_country',
 			workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
-			bias = u'user'
+			bias = 'user'
 		)
 	else:
 		countries = gmDemographicRecord.get_country_for_region(region = def_region)
 		if len(countries) == 1:
 			def_country = countries[0]['code_country']
 
-	ea = cNewPatientEAPnl(parent = parent, id = -1, country = def_country, region = def_region)
-	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = True)
+	ea = cNewPatientEAPnl(parent, -1, country = def_country, region = def_region)
+	dlg = gmEditArea.cGenericEditAreaDlg2(parent, -1, edit_area = ea, single_entry = True)
 	dlg.SetTitle(_('Adding new person'))
 	ea._PRW_lastname.SetFocus()
 	result = dlg.ShowModal()
 	pat = ea.data
-	dlg.Destroy()
+	dlg.DestroyLater()
 
 	if result != wx.ID_OK:
 		return False
@@ -138,7 +138,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		if self.default_region is not None:
 			self._PRW_region.SetText(value = self.default_region)
 
-		self._PRW_type.SetText(value = u'home')
+		self._PRW_type.SetText(value = 'home')
 		# FIXME: only use this if member of gm-doctors,
 		# FIXME: other than that check fallback_primary_provider
 		self._PRW_primary_provider.SetData(data = gmStaff.gmCurrentProvider()['pk_staff'])
@@ -148,44 +148,44 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 	def _refresh_ext_id_warning(self):
 		id_type = self._PRW_external_id_type.GetData()
 		if id_type is None:
-			self._LBL_id_exists.SetLabel(u'')
+			self._LBL_id_exists.SetLabel('')
 			return
 		val = self._TCTRL_external_id_value.GetValue().strip()
-		if val == u'':
-			self._LBL_id_exists.SetLabel(u'')
+		if val == '':
+			self._LBL_id_exists.SetLabel('')
 			return
 		if gmPerson.external_id_exists(pk_issuer = id_type, value = val) > 0:
 			self._LBL_id_exists.SetLabel(_('ID exists !'))
 		else:
-			self._LBL_id_exists.SetLabel(u'')
+			self._LBL_id_exists.SetLabel('')
 	#----------------------------------------------------------------
 	def _refresh_dupe_warning(self):
 		lname = self._PRW_lastname.GetValue().strip()
-		if lname == u'':
-			self._LBL_person_exists.SetLabel(u'')
+		if lname == '':
+			self._LBL_person_exists.SetLabel('')
 			return
 
 		dob = self._PRW_dob.GetData()
 		if dob is None:
-			self._LBL_person_exists.SetLabel(u'')
+			self._LBL_person_exists.SetLabel('')
 			return
 
-		fname = gmTools.none_if(self._PRW_firstnames.GetValue().strip()[:1], u'')
+		fname = gmTools.none_if(self._PRW_firstnames.GetValue().strip()[:1], '')
 
-		no_of_dupes = gmPerson.person_exists(lastnames = lname, firstnames = fname, dob = dob)
+		no_of_dupes = gmPerson.get_potential_person_dupes(lastnames = lname, firstnames = fname, dob = dob)
 		if no_of_dupes == 0:
-			lbl = u''
+			lbl = ''
 		elif no_of_dupes == 1:
 			lbl = _('One "%s, %s (%s)" already exists !') % (
 				lname,
-				gmTools.coalesce(fname, u'?', u'%s %%s. %s' % (gmTools.u_ellipsis, gmTools.u_ellipsis)),
+				gmTools.coalesce(fname, '?', '%s %%s. %s' % (gmTools.u_ellipsis, gmTools.u_ellipsis)),
 				gmDateTime.pydt_strftime(dob, '%Y %b %d', 'utf8')
 			)
 		else:
 			lbl = _('%s "%s, %s (%s)" already exist !') % (
 				no_of_dupes,
 				lname,
-				gmTools.coalesce(fname, u'?', u'%s %%s. %s' % (gmTools.u_ellipsis, gmTools.u_ellipsis)),
+				gmTools.coalesce(fname, '?', '%s %%s. %s' % (gmTools.u_ellipsis, gmTools.u_ellipsis)),
 				gmDateTime.pydt_strftime(dob, '%Y %b %d', 'utf8')
 			)
 
@@ -198,7 +198,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 			return True
 
 		if ctrl.GetValue().strip() != adr[field]:
-			wx.CallAfter(self._PRW_address_searcher.SetText, value = u'', data = None)
+			wx.CallAfter(self._PRW_address_searcher.SetText, value = '', data = None)
 			return True
 
 		return False
@@ -211,22 +211,22 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		self._PRW_zip.SetText(value = adr['postcode'], data = adr['postcode'])
 
 		self._PRW_street.SetText(value = adr['street'], data = adr['street'])
-		self._PRW_street.set_context(context = u'zip', val = adr['postcode'])
+		self._PRW_street.set_context(context = 'zip', val = adr['postcode'])
 
 		self._PRW_urb.SetText(value = adr['urb'], data = adr['urb'])
-		self._PRW_urb.set_context(context = u'zip', val = adr['postcode'])
+		self._PRW_urb.set_context(context = 'zip', val = adr['postcode'])
 
 		self._PRW_region.SetText(value = adr['l10n_region'], data = adr['code_region'])
-		self._PRW_region.set_context(context = u'zip', val = adr['postcode'])
+		self._PRW_region.set_context(context = 'zip', val = adr['postcode'])
 
 		self._PRW_country.SetText(value = adr['l10n_country'], data = adr['code_country'])
-		self._PRW_country.set_context(context = u'zip', val = adr['postcode'])
+		self._PRW_country.set_context(context = 'zip', val = adr['postcode'])
 	#----------------------------------------------------------------
 	def __identity_valid_for_save(self):
 		error = False
 
 		# name fields
-		if self._PRW_lastname.GetValue().strip() == u'':
+		if self._PRW_lastname.GetValue().strip() == '':
 			error = True
 			gmDispatcher.send(signal = 'statustext', msg = _('Must enter lastname.'))
 			self._PRW_lastname.display_as_valid(False)
@@ -267,7 +267,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 			gmTools.none_if(self._TCTRL_comment.GetValue().strip(), u'')
 		):
 			error = True
-			self.status_message = _('Duplicate person. Modify name and/or DOB or use comment to make unique.')
+			self.StatusText = _('Duplicate person. Modify name and/or DOB or use comment to make unique.')
 
 		return (not error)
 	#----------------------------------------------------------------
@@ -289,7 +289,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		no_of_filled_fields = 0
 
 		for field in fields_to_fill:
-			if field.GetValue().strip() != u'':
+			if field.GetValue().strip() != '':
 				no_of_filled_fields += 1
 				field.display_as_valid(True)
 
@@ -303,7 +303,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		# incompletely filled address ?
 		if no_of_filled_fields != len(fields_to_fill):
 			for field in fields_to_fill:
-				if field.GetValue().strip() == u'':
+				if field.GetValue().strip() == '':
 					field.display_as_valid(False)
 					field.SetFocus()
 			msg = _('To properly create an address, all the related fields must be filled in.')
@@ -346,8 +346,8 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 
 		# invalidate address searcher when any field edited
 		self._PRW_street.add_callback_on_lose_focus(self._invalidate_address_searcher)
-		wx.EVT_KILL_FOCUS(self._TCTRL_number, self._on_leaving_number)
-		wx.EVT_KILL_FOCUS(self._TCTRL_unit, self._on_leaving_unit)
+		self._TCTRL_number.Bind(wx.EVT_KILL_FOCUS, self._on_leaving_number)
+		self._TCTRL_unit.Bind(wx.EVT_KILL_FOCUS, self._on_leaving_unit)
 		self._PRW_urb.add_callback_on_lose_focus(self._invalidate_address_searcher)
 		self._PRW_region.add_callback_on_lose_focus(self._invalidate_address_searcher)
 
@@ -382,7 +382,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 			return True
 
 		firstname = self._PRW_firstnames.GetValue().strip()
-		if firstname == u'':
+		if firstname == '':
 			return True
 
 		gender = gmPerson.map_firstnames2gender(firstnames = firstname)
@@ -400,24 +400,24 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 	def _on_leaving_zip(self):
 		self.__perhaps_invalidate_address_searcher(self._PRW_zip, 'postcode')
 
-		zip_code = gmTools.none_if(self._PRW_zip.GetValue().strip(), u'')
-		self._PRW_street.set_context(context = u'zip', val = zip_code)
-		self._PRW_urb.set_context(context = u'zip', val = zip_code)
-		self._PRW_region.set_context(context = u'zip', val = zip_code)
-		self._PRW_country.set_context(context = u'zip', val = zip_code)
+		zip_code = gmTools.none_if(self._PRW_zip.GetValue().strip(), '')
+		self._PRW_street.set_context(context = 'zip', val = zip_code)
+		self._PRW_urb.set_context(context = 'zip', val = zip_code)
+		self._PRW_region.set_context(context = 'zip', val = zip_code)
+		self._PRW_country.set_context(context = 'zip', val = zip_code)
 
 		return True
 	#----------------------------------------------------------------
 	def _on_leaving_country(self):
 		self.__perhaps_invalidate_address_searcher(self._PRW_country, 'l10n_country')
 
-		country = gmTools.none_if(self._PRW_country.GetValue().strip(), u'')
-		self._PRW_region.set_context(context = u'country', val = country)
+		country = gmTools.none_if(self._PRW_country.GetValue().strip(), '')
+		self._PRW_region.set_context(context = 'country', val = country)
 
 		return True
 	#----------------------------------------------------------------
 	def _on_leaving_number(self, evt):
-		if self._TCTRL_number.GetValue().strip() == u'':
+		if self._TCTRL_number.GetValue().strip() == '':
 			adr = self._PRW_address_searcher.address
 			if adr is None:
 				return True
@@ -428,11 +428,11 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		return True
 	#----------------------------------------------------------------
 	def _on_leaving_unit(self, evt):
-		if self._TCTRL_unit.GetValue().strip() == u'':
+		if self._TCTRL_unit.GetValue().strip() == '':
 			adr = self._PRW_address_searcher.address
 			if adr is None:
 				return True
-			self._TCTRL_unit.SetValue(gmTools.coalesce(adr['subunit'], u''))
+			self._TCTRL_unit.SetValue(gmTools.coalesce(adr['subunit'], ''))
 			return True
 
 		self.__perhaps_invalidate_address_searcher(self._TCTRL_unit, 'subunit')
@@ -461,7 +461,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 	# generic Edit Area mixin API
 	#----------------------------------------------------------------
 	def _valid_for_save(self):
-		if self._PRW_primary_provider.GetValue().strip() == u'':
+		if self._PRW_primary_provider.GetValue().strip() == '':
 			self._PRW_primary_provider.display_as_valid(True)
 		else:
 			if self._PRW_primary_provider.GetData() is None:
@@ -472,7 +472,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 	#----------------------------------------------------------------
 	def _save_as_new(self):
 
-		if self._PRW_dob.GetValue().strip() == u'':
+		if self._PRW_dob.GetValue().strip() == '':
 			if not _empty_dob_allowed():
 				self._PRW_dob.display_as_valid(False)
 				self._PRW_dob.SetFocus()
@@ -483,7 +483,8 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 			gender = self._PRW_gender.GetData(),
 			dob = self._PRW_dob.GetData(),
 			lastnames = self._PRW_lastname.GetValue().strip(),
-			firstnames = self._PRW_firstnames.GetValue().strip()
+			firstnames = self._PRW_firstnames.GetValue().strip(),
+			comment = gmTools.none_if(self._TCTRL_comment.GetValue().strip(), '')
 		)
 		if new_identity is None:
 			gmGuiHelpers.gm_show_error (
@@ -491,8 +492,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 				error = _(
 					'Failed to create person. Does it already exist ?\n'
 					'\n'
-					'If so you need to (temporarily) modify, say, the\n'
-					'first or last name.'
+					'If so you need to add a unique comment.'
 				)
 			)
 			return False
@@ -500,18 +500,18 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 
 		new_identity['dob_is_estimated'] = self._CHBOX_estimated_dob.GetValue()
 		val = self._TCTRL_tob.GetValue().strip()
-		if val != u'':
+		if val != '':
 			new_identity['tob'] = pydt.time(int(val[:2]), int(val[3:5]))
 		new_identity['title'] = gmTools.none_if(self._PRW_title.GetValue().strip())
 
 		prov = self._PRW_primary_provider.GetData()
 		if prov is not None:
 			new_identity['pk_primary_provider'] = prov
-		new_identity['comment'] = gmTools.none_if(self._TCTRL_comment.GetValue().strip(), u'')
+		#new_identity['comment'] = gmTools.none_if(self._TCTRL_comment.GetValue().strip(), '')
 		new_identity.save()
 		_log.info('new identity updated: %s' % new_identity)
 
-		new_identity.set_nickname(nickname = gmTools.none_if(self._PRW_nickname.GetValue().strip(), u''))
+		new_identity.set_nickname(nickname = gmTools.none_if(self._PRW_nickname.GetValue().strip(), ''))
 		_log.info('nickname set on new identity: %s' % new_identity)
 
 		# address
@@ -528,7 +528,7 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 					urb = self._PRW_urb.GetValue().strip(),
 					region_code = self._PRW_region.GetData(),
 					country_code = self._PRW_country.GetData(),
-					subunit = gmTools.none_if(self._TCTRL_unit.GetValue().strip(), u''),
+					subunit = gmTools.none_if(self._TCTRL_unit.GetValue().strip(), ''),
 					id_type = self._PRW_type.GetData()
 				)
 			except gmPG2.dbapi.InternalError:
@@ -563,24 +563,24 @@ class cNewPatientEAPnl(wxgNewPatientEAPnl.wxgNewPatientEAPnl, gmEditArea.cGeneri
 		channel_name = self._PRW_channel_type.GetValue().strip()
 		pk_channel_type = self._PRW_channel_type.GetData()
 		if pk_channel_type is None:
-			if channel_name == u'':
-				channel_name = u'homephone'
+			if channel_name == '':
+				channel_name = 'homephone'
 		new_identity.link_comm_channel (
 			comm_medium = channel_name,
 			pk_channel_type = pk_channel_type,
-			url = gmTools.none_if(self._TCTRL_phone.GetValue().strip(), u''),
+			url = gmTools.none_if(self._TCTRL_phone.GetValue().strip(), ''),
 			is_confidential = False
 		)
 
 		# external ID
 		pk_type = self._PRW_external_id_type.GetData()
 		id_value = self._TCTRL_external_id_value.GetValue().strip()
-		if (pk_type is not None) and (id_value != u''):
+		if (pk_type is not None) and (id_value != ''):
 			new_identity.add_external_id(value = id_value, pk_type = pk_type)
 
 		# occupation
 		new_identity.link_occupation (
-			occupation = gmTools.none_if(self._PRW_occupation.GetValue().strip(), u'')
+			occupation = gmTools.none_if(self._PRW_occupation.GetValue().strip(), '')
 		)
 
 		self.data = new_identity
@@ -607,7 +607,7 @@ if __name__ == "__main__":
 	if len(sys.argv) < 2:
 		sys.exit()
 
-	if sys.argv[1] != u'test':
+	if sys.argv[1] != 'test':
 		sys.exit()
 
 #	from Gnumed.pycommon import gmPG2
